@@ -1,21 +1,10 @@
 /*
- * Copyright 2009 Mathias Kraus <k.hias@gmx.de>
- * Copyright 2007-2008 Thomas Gallinari <tg8187@yahoo.fr>
- * Copyright 2007-2008 Alexandre Galinier <alex.galinier@hotmail.com>
- *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License as
- * published by the Free Software Foundation; either version 2 of
- * the License, or (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- */
+    SPDX-FileCopyrightText: 2009 Mathias Kraus <k.hias@gmx.de>
+    SPDX-FileCopyrightText: 2007-2008 Thomas Gallinari <tg8187@yahoo.fr>
+    SPDX-FileCopyrightText: 2007-2008 Alexandre Galinier <alex.galinier@hotmail.com>
+
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #ifndef GAME_H
 #define GAME_H
@@ -330,11 +319,6 @@ Q_SIGNALS:
     */
     void bombCreated(Bomb* bomb);
 
-    /**
-    * Emitted when a bomb was removed.
-    */
-    void bombRemoved(Bomb* bomb);
-
     /**
     * Emitted when something to display has changed.
     */
